FitGridTree<T> class

Turns flat rows into a tree.

Annotations

Constructors

FitGridTree({required List<T> childrenOf(T row), bool initiallyExpanded = false})
const

Properties

childrenOf → List<T> Function(T row)
A row's children, or an empty list for a leaf.
final
hashCode → int
The hash code for this object.
no setterinherited
initiallyExpanded → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

hasChildren(T row) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited